package com.moyoung.moyoung_ble_plugin.event;

import android.util.Log;

import com.crrepa.ble.conn.CRPBleConnection;
import com.crrepa.ble.conn.listener.CRPBleConnectionStateListener;
import com.crrepa.ble.conn.listener.CRPCameraOperationListener;
import com.moyoung.moyoung_ble_plugin.base.BaseConnectionEventChannelHandler;
import com.moyoung.moyoung_ble_plugin.common.GsonUtils;
import com.moyoung.moyoung_ble_plugin.method.ConnectionMethodHandler;
import com.moyoung.moyoung_ble_plugin.model.ConnectStateBean;

import java.util.Timer;
import java.util.TimerTask;

import io.flutter.plugin.common.MethodCall;

class ConnectionStateHandler extends BaseConnectionEventChannelHandler {
    private final static String TAG = ConnectionStateHandler.class.getSimpleName();

    @Override
    public void setConnListener(CRPBleConnection connection, MethodCall call) {
        connection.setConnectionStateListener(newState -> {
            if (eventSink == null) {
                return;
            }
            switch (newState) {
                case CRPBleConnectionStateListener.STATE_CONNECTED:
                    ConnectionMethodHandler.isConnected = true;
                    supportDelayTime(connection);
                    break;
                case CRPBleConnectionStateListener.STATE_DISCONNECTED:
                    if (ConnectionMethodHandler.autoConnect) {
                        if (ConnectionMethodHandler.enableBLE) {
                            Timer timer = new Timer();
                            timer.schedule(new TimerTask() {
                                @Override
                                public void run() {
                                    connection.connect();
                                    timer.cancel();
                                }
                            }, 3000, 3000);
                        }
                    } else {
                        connection.close();
                    }
                default:
                    ConnectionMethodHandler.isConnected = false;
                    break;
            }
            ConnectStateBean connectStateBean = new ConnectStateBean();
            connectStateBean.setConnectState(newState);
            connectStateBean.setAutoConnect(ConnectionMethodHandler.autoConnect);
            String jsonStr = GsonUtils.get().toJson(connectStateBean, ConnectStateBean.class);
//            Log.i(TAG, "setConnListener: " + jsonStr);
            activity.runOnUiThread(() -> eventSink.success(jsonStr));
        });
    }

    public void supportDelayTime(CRPBleConnection connection) {
        ConnectionMethodHandler.isConnectedCall = true;
        // 每次连接都要把变量先赋为默认值，因为延迟监听不一定进入
        ConnectionMethodHandler.supportDelayTime(false);
        connection.queryDelayTaking();
    }

}
